import numpy as np

def separate_data(array, number, pixel, ndv):
    """
    Separate the data to inbound and outbound, where inbound is data to be sampled for interpolation, and outbound is data
    with boundaries to avoid edge effects.

    Parameters:
        array (numpy.ndarray): Input 2D numpy array.
        number (int): Number of pixels to be removed from each edge of the array.
        pixel (int): Number of additional boundary pixels to preserve with their original values.
        ndv: No-data value.

    Returns:
        inbound_result (numpy.ndarray): Inbound data (sampled for interpolation).
        outbound_result (numpy.ndarray): Outbound data (with boundary to avoid edge effect).
    """
    # Make a copy of the input array to store the result
    result = array.copy()

    # Calculate the effective number of pixels to remove considering additional boundary pixels
    number = number + pixel - 1 if pixel > 1 else number

    # Set boundaries with ndv (outbound data)
    result[:, :number + 1] = ndv
    result[:, -number - 1:] = ndv
    result[:number + 1, :] = ndv
    result[-number - 1:, :] = ndv

    # Preserve additional boundary pixels with their original values
    result[0:pixel, :] = array[0:pixel, :]
    result[:, 0:pixel] = array[:, 0:pixel]
    result[-pixel:, :] = array[-pixel:, :]
    result[:, -pixel:] = array[:, -pixel:]

    outbound_result = result
    # Extract inbound data
    inbound_result = array[number + 1:-number - 1, number + 1:-number - 1]

    return inbound_result, outbound_result

